@@ -23,10 +23,17 @@ galleryCreate <- function(gallery, dir){
   script <- "gallery.js"
   style <- "styles.css"
   mode <- 1
-  if(!is.null(gallery$options$mode) && gallery$options$mode==2){
-    mode <- 2
-    script <- "gallery2.js"
-    style <- "styles2.css"
+  if(!is.null(gallery$options$mode)){
+    if(gallery$options$mode==2){
+      mode <- 2
+      script <- "gallery2.js"
+      style <- "styles2.css"
+    }else if(gallery$options$mode==3){
+      mode <- 3
+      script <- "gallery3.js"
+      style <- "styles3.css"
+      gallery$tree <- NULL
+    }
   }
   if(!is.null(gallery$tree)){
     if(mode==2){
@@ -57,15 +64,30 @@ galleryCreate <- function(gallery, dir){
   }
 }
 
+mgmtNoFilterCols <- function(options,noFilterCols,nodenames){
+    if(!is.null(noFilterCols)){
+      noFilterCols <- as.character(noFilterCols)
+      coldiff <- setdiff(noFilterCols,nodenames)
+      if(length(coldiff)){
+        noFilterCols <- intersect(noFilterCols,nodenames)
+        warning(paste0("noFilterCols: some columns (",paste0(coldiff,collapse=", "),") mising in nodes data frame"))
+      }
+      options[["noFilterCols"]] <- noFilterCols
+    }
+    return(options)
+}
+
 gallery_rd3 <- function(nodes, name = NULL, label = NULL, color = NULL,
     border = NULL, ntext = NULL, info = NULL, infoFrame = c("right","left"),
-    image = NULL, zoom = 1, itemsPerRow = NULL, main = NULL, note = NULL,
-    showLegend = TRUE, frequencies = FALSE, labelTooltip = TRUE,
+    image = NULL, imageCopy = NULL, noFilterCols = NULL, zoom = 1, itemsPerRow = NULL, main = NULL,
+    note = NULL, showLegend = TRUE, frequencies = FALSE, labelTooltip = TRUE,
     cexTooltip = 1, help = NULL, helpOn = FALSE, tutorial = FALSE,
     description = NULL, descriptionWidth = NULL, roundedItems = FALSE,
     ntextctrl = FALSE, controls = 1:5, cex = 1, defaultColor = "#1f77b4",
     language = c("en", "es", "ca"), dir = NULL){
 
+  nodes <- as.data.frame(nodes)
+
   if(is.null(name)){
     name <- colnames(nodes)[1]
   }
@@ -134,9 +156,12 @@ gallery_rd3 <- function(nodes, name = NULL, label = NULL, color = NULL,
       warning("image: name must match in nodes colnames.")
     }else{
       options[["imageItems"]] <- image
+      options <- checkColumn(options,"imageCopy",imageCopy)
     }
   }
 
+  options <- mgmtNoFilterCols(options,noFilterCols,colnames(nodes))
+
   # create gallery
   gallery <- structure(list(nodes=nodes,options=options),class="gallery_rd3")
 
@@ -149,11 +174,14 @@ gallery_rd3 <- function(nodes, name = NULL, label = NULL, color = NULL,
   return(gallery)
 }
 
-gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
-    order = NULL, decreasing = FALSE, ntext = NULL, mainframeHeight = NULL,
-    mainframeWidth = NULL, image = NULL, zoom = NULL, main = NULL, note = NULL,
+gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL, order = NULL,
+    decreasing = FALSE, ntext = NULL,
+    mainframeHeight = NULL, mainframeWidth = NULL, mainframeImage = 0,
+    image = NULL, imageCopy = NULL, noFilterCols = NULL, zoom = NULL, main = NULL, note = NULL,
     frequencies = FALSE, tutorial = FALSE, tableButton = FALSE, export = FALSE,
-    colorScheme = 0, language = c("en", "es", "ca"), dir = NULL){
+    search = TRUE, colorScheme = 0,  language = c("en", "es", "ca"), dir = NULL){
+
+  nodes <- as.data.frame(nodes)
 
   if(is.null(name)){
     name <- colnames(nodes)[1]
@@ -195,6 +223,14 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
     }
   }
 
+  if(!is.null(mainframeImage)){
+    if(!is.numeric(mainframeImage)){
+      warning("mainframeImage: must be numeric")
+    }else{
+      options[["mainframeImage"]] <- mainframeImage
+    }
+  }
+
   if(!is.null(zoom)){
     if(!(is.numeric(zoom) && zoom>=0.1 && zoom<=1)){
       warning("zoom: must be numeric between 0.1 and 1")
@@ -205,6 +241,7 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
   if (!is.null(main)) options[["main"]] <- main
   if (!is.null(note)) options[["note"]] <- note
 
+  options <- showSomething(options,"search",search)
   options <- showSomething(options,"tutorial",tutorial)
   options <- showSomething(options,"showTable",tableButton)
   options <- showSomething(options,"exportExcel",export)
@@ -219,9 +256,12 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
     }else{
       options[["imageItems"]] <- image
       nodes[,image] <- sub('\\|.*','', nodes[,image])
+      options <- checkColumn(options,"imageCopy",imageCopy)
     }
   }
 
+  options <- mgmtNoFilterCols(options,noFilterCols,colnames(nodes))
+
   options[["mode"]] <- 2
 
   # create gallery
@@ -233,6 +273,107 @@ gallery2_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL,
   return(gallery)
 }
 
+gallery3_rd3 <- function(nodes, name = NULL, label = NULL, subtitle = NULL, order = NULL,
+    decreasing = FALSE, ntext = NULL,
+    mainframeHeight = NULL, mainframeWidth = NULL, mainframeImage = 0,
+    image = NULL, imageCopy = NULL, imageRatio = NULL, noFilterCols = NULL, zoom = NULL, main = NULL, note = NULL,
+    search = TRUE, cex = 1, language = c("en", "es", "ca"), dir = NULL){
+
+  nodes <- as.data.frame(nodes)
+
+  if(is.null(name)){
+    name <- colnames(nodes)[1]
+  }
+  rownames(nodes) <- nodes[[name]]
+
+  # options
+  options <- list(nodeName = name)
+  if(is.null(label)){
+    options[["nodeLabel"]] <- name
+  }else{
+    options <- checkColumn(options,"nodeLabel",label)
+  }
+  options <- checkColumn(options,"nodeSubtitle",subtitle)
+  if(is.character(order)){
+    options[["nodeOrder"]] <- order
+  }
+  if(is.logical(decreasing)){
+    options[["decreasing"]] <- decreasing
+  }
+  options <- checkColumn(options,"nodeText",ntext)
+  if(!is.null(options[["nodeText"]])){
+    nodes[,options[["nodeText"]]] <- sub('\\|.*','', nodes[,options[["nodeText"]]])
+  }
+
+  if(!is.null(mainframeHeight)){
+    if(!is.numeric(mainframeHeight)){
+      warning("mainframeHeight: must be numeric")
+    }else{
+      options[["mainframeHeight"]] <- mainframeHeight
+    }
+  }
+
+  if(!is.null(mainframeWidth)){
+    if(!is.numeric(mainframeWidth)){
+      warning("mainframeWidth: must be numeric")
+    }else{
+      options[["mainframeWidth"]] <- mainframeWidth
+    }
+  }
+
+  if(!is.null(mainframeImage)){
+    if(!is.numeric(mainframeImage)){
+      warning("mainframeImage: must be numeric")
+    }else{
+      options[["mainframeImage"]] <- mainframeImage
+    }
+  }
+
+  if(!is.null(zoom)){
+    if(!is.numeric(zoom)){
+      warning("zoom: must be numeric")
+    }
+    options[["zoom"]] <- zoom
+  }
+
+  if(!is.null(imageRatio)){
+    if(!is.numeric(imageRatio)){
+      warning("imageRatio: must be numeric")
+    }
+    options[["imageRatio"]] <- imageRatio
+  }
+
+  if (!is.null(main)) options[["main"]] <- main
+  if (!is.null(note)) options[["note"]] <- note
+
+  options <- showSomething(options,"search",search)
+  options[["cex"]] <- check_cex(cex)
+  options[["language"]] <- checkLanguage(language)
+
+  if (!is.null(image)){
+    image <- image[1]
+    if(!image %in% colnames(nodes)){
+      warning("image: name must match in nodes colnames.")
+    }else{
+      options[["imageItems"]] <- image
+      nodes[,image] <- sub('\\|.*','', nodes[,image])
+      options <- checkColumn(options,"imageCopy",imageCopy)
+    }
+  }
+
+  options <- mgmtNoFilterCols(options,noFilterCols,colnames(nodes))
+
+  options[["mode"]] <- 3
+
+  # create gallery
+  gallery <- structure(list(nodes=nodes,options=options),class="gallery_rd3")
+
+  if(!is.null(dir)){
+    galleryCreate(gallery,dir)
+  }
+  return(gallery)
+}
+
 table2links <- function(x){
       tree <- as.matrix(x)
       tree2 <- list()
