@@ -122,10 +122,13 @@ var texts = {
     Table: "Table",
     goto: "go to",
     showonlyselecteditems: "Show only selected items",
+    Relations: "Relations",
     Variable: "Variable",
     Value: "Value",
     highlightneighbors: "Highlight neighbors",
     clearfilters: "Clear filters",
     close: "Close",
-    filtermenu: "Filter menu"
+    filtermenu: "Filter menu",
+    noresults: "No results",
+    jointfilter: "Joint filter"
   };
